easy_dna
========

.. image:: https://github.com/Edinburgh-Genome-Foundry/easy_dna/actions/workflows/build.yml/badge.svg
    :target: https://github.com/Edinburgh-Genome-Foundry/easy_dna/actions/workflows/build.yml
    :alt: GitHub CI build status

Easy_dna is a Python library implementing useful routines for manipulating DNA
sequences, either as "ATGC" strings or Biopython records. It aims at providing
a simpler interface than Biopython for common operations related to DNA sequence
design and genbank generation.

Easy_dna was originally created to gather useful methods repeatedly used in the
different software projects of the Edinburgh Genome Foundry for DNA design and
manufacturing.

See the API reference `here <https://edinburgh-genome-foundry.github.io/easy_dna/>`_.


Installation
------------

You can install easy_dna through PIP:

.. code::

    pip install easy_dna

Alternatively, you can unzip the sources in a folder and type:

.. code::

    python setup.py install


License = MIT
-------------

Easy_dna is an open-source software originally written at the `Edinburgh Genome Foundry
<http://edinburgh-genome-foundry.github.io/home.html>`_ by `Zulko <https://github.com/Zulko>`_
and `released on Github <https://github.com/Edinburgh-Genome-Foundry/easy_dna>`_ under the MIT licence (Copyright 2019 Edinburgh Genome Foundry). Everyone is welcome to contribute!


More biology software
---------------------

.. image:: https://raw.githubusercontent.com/Edinburgh-Genome-Foundry/Edinburgh-Genome-Foundry.github.io/master/static/imgs/logos/egf-codon-horizontal.png
  :target: https://edinburgh-genome-foundry.github.io/

Easy_dna is part of the `EGF Codons <https://edinburgh-genome-foundry.github.io/>`_ synthetic biology software suite for DNA design, manufacturing and validation.
